==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebStepDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebStepDescription } from "./WebStepDescription";
/**
 * @hidden
 */
export let WebStepDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStepDescriptionMetadata extends Base {
        static b(a) {
            if (WebStepDescriptionMetadata.a == null) {
                WebStepDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStepDescriptionMetadata.c(WebStepDescriptionMetadata.a);
            }
            if (a.k(WebStepDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebStepDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Step");
            a.item("__tagNameWC", "String:igc-step");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Invalid", "Boolean");
            a.item("Active", "Boolean");
            a.item("Optional", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Complete", "Boolean");
            a.item("PreviousComplete", "Boolean");
            a.item("StepType", "ExportedType:string:StepStepType");
            a.item("StepType@stringUnion", "WebComponents;React");
            a.item("StepType@names", "Indicator;Title;Full");
            a.item("TitlePosition", "ExportedType:string:StepTitlePosition");
            a.item("TitlePosition@stringUnion", "WebComponents;React");
            a.item("TitlePosition@names", "Top;Bottom;Start;End");
            a.item("Orientation", "ExportedType:string:StepOrientation");
            a.item("Orientation@stringUnion", "WebComponents;React");
            a.item("Orientation@names", "Vertical;Horizontal");
            a.item("Index", "Number:double");
            a.item("ContentTop", "Boolean");
            a.item("LinearDisabled", "Boolean");
            a.item("Visited", "Boolean");
        }
        static d(a) {
            WebStepDescriptionMetadata.b(a);
            a.ac("WebStep", () => new WebStepDescription());
            a.ab("WebStep", WebStepDescriptionMetadata.a);
        }
    }
    WebStepDescriptionMetadata.$t = /*@__PURE__*/ markType(WebStepDescriptionMetadata, 'WebStepDescriptionMetadata');
    WebStepDescriptionMetadata.a = null;
    return WebStepDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebStepDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebStepDescription } from "./WebStepDescription";
/**
 * @hidden
 */
export let WebStepDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStepDescriptionMetadata extends Base {
        static b(a) {
            if (WebStepDescriptionMetadata.a == null) {
                WebStepDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStepDescriptionMetadata.c(WebStepDescriptionMetadata.a);
            }
            if (a.k(WebStepDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebStepDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Step");
            a.item("__tagNameWC", "String:igc-step");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Invalid", "Boolean");
            a.item("Active", "Boolean");
            a.item("Optional", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Complete", "Boolean");
        }
        static d(a) {
            WebStepDescriptionMetadata.b(a);
            a.ae("WebStep", () => new WebStepDescription());
            a.ad("WebStep", WebStepDescriptionMetadata.a);
        }
    }
    WebStepDescriptionMetadata.$t = /*@__PURE__*/ markType(WebStepDescriptionMetadata, 'WebStepDescriptionMetadata');
    WebStepDescriptionMetadata.a = null;
    return WebStepDescriptionMetadata;
})();
